@@ -5,9 +5,9 @@ from python_to_pythonjs import main as python_to_pythonjs
 from pythonjs import main as pythonjs
 
 
-def main(script):
-    return pythonjs(python_to_pythonjs(script))
+def main():
+    return pythonjs(python_to_pythonjs(sys.stdin.read()))
 
 
 if __name__ == '__main__':
-    print main(sys.stdin.read())
+    print main()
